@@ -61,7 +61,7 @@ class tdcoa:
     systemspath = ''
     filesetpath = ''
     outputpath = ''
-    version = "0.3.9.5.2"
+    version = "0.3.9.5.4"
 
     # dictionaries
     secrets = {}
@@ -94,10 +94,6 @@ class tdcoa:
 
         self.unique_id = dt.datetime.now().strftime("%m%d%Y%H%M")  # unique id to append to table
 
-        # todo remove all references to skipgit and skipdbs?
-        self.skipgit = False
-        self.skipdbs = False
-
         # filesets.yaml is validated at download time
 
         self.reload_config()
@@ -148,6 +144,14 @@ class tdcoa:
         self.utils.log('time', str(dt.datetime.now()))
         self.utils.log('tdcoa version', self.version)
 
+        # for GUI - make sure coa.py is present in approot folder:
+        startguifile_src = os.path.join(os.path.dirname(tdcsm.__file__), 'coa.py')
+        startguifile_dst = os.path.join(self.approot, 'coa.py')
+        if not os.path.isfile(startguifile_dst) and os.path.isfile(startguifile_src):
+            with open(startguifile_src) as f1:
+                with open(startguifile_dst, 'w') as f2:
+                    f2.write(f1.read())
+
         # remove 2 default files -> config, source_systems
         # todo NOTE: currently not removing secrets file because it shouldnt require format updates
         if self.refresh_defaults:
@@ -248,32 +252,17 @@ class tdcoa:
         self.utils.log('loading dictionary', 'settings')
         self.settings = configyaml['settings']
         self.utils.check_setting(self.settings,
-                           required_item_list=['githost', 'gitfileset', 'gitmotd', 'localfilesets', 'skip_git',
-                                               'skip_dbs',
+                           required_item_list=['githost', 'gitfileset', 'gitmotd', 'localfilesets',
                                                'run_non_fileset_folders', 'customer_connection_type'],
                            defaults=['https://raw.githubusercontent.com/tdcoa/sql/master/',
                                      'filesets.yaml',
                                      'motd.txt',
                                      '{download}/filesets.yaml',
-                                     'False',
-                                     'False',
                                      'True',
                                      'sqlalchemy']
                            )
         self.filesetpath = self.settings['localfilesets']
 
-        if 'skip_git' in self.settings and str(self.settings['skip_git']).lower() in ['true']:
-            self.utils.log('setting flag skip_git active, skipping all git pulls')
-            self.skipgit = True
-        else:
-            self.skipgit = False
-
-        if 'skip_dbs' in self.settings and str(self.settings['skip_dbs']).lower() in ['true']:
-            self.utils.log('setting flag skip_dbs active, skipping all database pulls')
-            self.skipdbs = True
-        else:
-            self.skipdbs = False
-
         # create missing folders
         for nm, subfo in self.folders.items():
             fopath = os.path.join(self.approot, subfo)
@@ -367,16 +356,12 @@ class tdcoa:
 
         filesetcontent = ''
 
-        # download any control files first (filesets.yaml, motd.txt, etc.)
+        # download any control files first (motd.html, etc.)
         # motd
         giturl = githost + self.settings['gitmotd']
         self.utils.log('downloading "motd.html" from github')
         self.utils.log('  requesting url', giturl)
-        if self.skipgit:
-            self.utils.log('  setting: skip_git = True', 'skipping download')
-            filecontent = 'default message'
-        else:
-            filecontent = requests.get(giturl).text
+        filecontent = requests.get(giturl).text
         with open(os.path.join(self.approot, 'motd.html'), 'w') as fh:
             fh.write(filecontent)
 
@@ -385,6 +370,7 @@ class tdcoa:
         webbrowser.open(file_url)
 
         # delete all pre-existing download folders
+        # Commented the below code, in order to make the script download only if the files doesn't exist
         self.utils.recursively_delete_subfolders(os.path.join(self.approot, self.folders['download']))
 
         # set proper githost for filesets
@@ -434,12 +420,18 @@ class tdcoa:
                                             collection_match = False
 
                                     # only download file if dbsversion and collection match
+
+                                    savefile = os.path.join(savepath, file_dict['gitfile'].split('/')[-1])  # save path
+                                    # Skip download if file already exists
+                                    file_exists = os.path.exists(savefile)
+                                    print(str(savefile))
+                                    if file_exists == True:
+                                        self.utils.log('  File %s already exists in the download folder, so skipping download' % str(file_dict['gitfile'].split('/')[-1]))
+                                        continue
                                     if dbversion_match and collection_match:
                                         self.utils.log('   downloading file', file_dict['gitfile'])
                                         giturl = githost + file_dict['gitfile']
                                         self.utils.log('    %s' % giturl)
-                                        savefile = os.path.join(savepath, file_dict['gitfile'].split('/')[-1])  # save path
-
                                         response = requests.get(giturl)
                                         if response.status_code == 200:
 
@@ -494,14 +486,47 @@ class tdcoa:
                         # define paths:
                         srcpath = os.path.join(self.approot, self.folders['download'], setname)
                         dstpath = os.path.join(self.approot, self.folders['sql'], sysname)
-                        if not os.path.exists(dstpath):
-                            os.mkdir(dstpath)
                         dstpath = os.path.join(dstpath, setname)
+                        if not os.path.exists(dstpath):
+                            os.makedirs(dstpath)
 
                         # purge existing, and copy over
                         if overwrite:
                             self.utils.recursive_delete(dstpath)
-                        self.utils.recursive_copy(srcpath, dstpath)
+
+                        # loop through downloaded files and copy them to sql_store folder
+                        # only copy if dbsversion and collection match
+                        for downloaded_file in os.listdir(srcpath):
+                            dbsversion_match = True
+                            collection_match = True
+
+                            # match downloaded file to fileset object so that we can compare collection & dbsversion
+                            # note: fileset may not always have dbsversion or collection listed. always copy if thats true
+                            for file_object, file_values in self.filesets['feature_usage']['files'].items():
+                                if downloaded_file == file_values['gitfile'].split('/')[-1]:
+                                    if 'dbsversion' in file_values:
+                                        if sysobject['dbsversion'] not in file_values['dbsversion']:
+                                            dbsversion_match = False  # non-matching dbsversion: dont copy
+
+                                    if 'collection' in file_values:
+                                        if sysobject['collection'] not in file_values['collection']:
+                                            collection_match = False  # non-matching collection: dont copy
+
+                                    break
+
+                            # only copy if dbsversion and collection match (if given)
+                            # todo add logging regarding which files are being skipped / copied
+                            if dbsversion_match and collection_match:
+                                shutil.copyfile(os.path.join(srcpath, downloaded_file), os.path.join(dstpath, downloaded_file))
+
+
+
+
+
+
+
+
+
 
         self.utils.log('\ndone!')
         self.utils.log('time', str(dt.datetime.now()))
@@ -640,6 +665,8 @@ class tdcoa:
                                 # define paths
                                 sqlpath = os.path.join(self.approot, self.folders['sql'], sysfolder, setfolder)
                                 runpath = os.path.join(self.approot, self.folders['run'], sysfolder)
+
+                                # todo combine into single makedirs statement instead of 2 mkdir
                                 if not os.path.isdir(runpath):
                                     self.utils.log('  creating system folder', runpath)
                                     os.mkdir(runpath)
@@ -947,7 +974,6 @@ class tdcoa:
                                     conn = self.utils.open_connection(
                                         conntype=self.systems[sysname]['driver'],
                                         encryption=self.systems[sysname]['encryption'],
-                                        skip=self.skipdbs,
                                         system=self.systems[sysname])  # <------------------------------- Connect to the database
 
                                     # loop thru all sql files:
@@ -970,8 +996,7 @@ class tdcoa:
                                                 sqlcmd = self.utils.get_special_commands(sql)
                                                 sql = sqlcmd.pop('sql', '')
 
-                                                df = self.utils.open_sql(conn, sql,
-                                                                   skip=self.skipdbs)  # <--------------------- Run SQL
+                                                df = self.utils.open_sql(conn, sql)  # <--------------------- Run SQL
 
                                                 if len(df) != 0:  # Save non-empty returns to .csv
 
@@ -989,7 +1014,7 @@ class tdcoa:
                                                     # Col names will be merged upon save
                                                     col_names = []
                                                     if conn['type'] not in ('sqlalchemy', 'teradataml'):
-                                                        col_names = self.utils.open_sql(conn, sql, skip=self.skipdbs, columns=True)
+                                                        col_names = self.utils.open_sql(conn, sql, columns=True)
 
                                                     # once built, append output folder, SiteID on the front, iterative counter if duplicates
                                                     # csvfile = os.path.join(outputfo, sqlcmd['save'])
@@ -1125,8 +1150,7 @@ class tdcoa:
 
         transcend = self.utils.open_connection(
             'teradataml',
-            system=self.transcend,
-            skip=self.skipdbs)  # <--------------------------------- Connect
+            system=self.transcend)  # <--------------------------------- Connect
 
         # Walk the directory structure looking for upload_manifest.json files
         for workpath, subfo, files in os.walk(outputpath):
